@@ -1,10 +1,16 @@
 #include "mailfront.h"
+#include <stdlib.h>
+#include <string.h>
+#include <bglibs/striter.h>
 
+static RESPONSE(too_big, 552, "5.2.3 The message would exceed the maximum message size.");
 static RESPONSE(too_long, 552, "5.2.3 Sorry, that message exceeds the maximum message length.");
 static RESPONSE(hops, 554, "5.6.0 This message is looping, too many hops.");
 static RESPONSE(manyrcpt, 550, "5.5.3 Too many recipients");
+static RESPONSE(manymsgs, 550, "5.5.0 Too many messages");
 
 static unsigned rcpt_count = 0;
+static unsigned msg_count = 0;
 static unsigned long data_bytes; /* Total number of data bytes */
 static unsigned count_rec;	/* Count of the Received: headers */
 static unsigned count_dt;	/* Count of the Delivered-To: headers */
@@ -35,6 +41,15 @@ static const response* init(void)
   return 0;
 }
 
+static const response* helo(str* hostname, str* capabilities)
+{
+  if (!str_cats(capabilities, "SIZE ")) return &resp_oom;
+  if (!str_catu(capabilities, session_getnum("maxdatabytes", 0))) return &resp_oom;
+  if (!str_catc(capabilities, '\n')) return &resp_oom;
+  return 0;
+  (void)hostname;
+}
+
 static const response* reset(void)
 {
   minenv("maxdatabytes", "DATABYTES");
@@ -42,17 +57,49 @@ static const response* reset(void)
   return 0;
 }
 
-static const response* sender(str* r)
+static const char* find_param(const str* params, const char* name)
 {
+  const long len = strlen(name);
+  striter i;
+  striter_loop(&i, params, 0) {
+    if (strncasecmp(i.startptr, name, len) == 0) {
+      if (i.startptr[len] == '0')
+	return i.startptr + len;
+      if (i.startptr[len] == '=')
+	return i.startptr + len + 1;
+    }
+  }
+  return 0;
+}
+
+static const response* sender(str* r, str* params)
+{
+  unsigned long maxdatabytes;
+  unsigned long size;
+  const char* param;
+
+  minenv("maxmsgs", "MAXMSGS");
+  if (msg_count >= session_getnum("maxmsgs", ~0UL))
+    return &resp_manymsgs;
+
   /* This MUST be done as a sender match to make sure SMTP "MAIL FROM"
    * commands with a SIZE parameter can be rejected properly. */
   minenv("maxdatabytes", "DATABYTES");
   minenv("maxrcpts", "MAXRCPTS");
+  /* Look up the size limit after handling the sender,
+     in order to honour limits set in the mail rules. */
+  maxdatabytes = session_getnum("maxdatabytes", ~0UL);
+  if ((param = find_param(params, "SIZE")) != 0 &&
+      (size = strtoul(param, (char**)&param, 10)) > 0 &&
+      *param == 0 &&
+      size > maxdatabytes)
+    return &resp_too_big;
   (void)r;
   return 0;
+  (void)params;
 }
 
-static const response* recipient(str* r)
+static const response* recipient(str* r, str* params)
 {
   unsigned long maxrcpts = minenv("maxrcpts", "MAXRCPTS");
   minenv("maxdatabytes", "DATABYTES");
@@ -61,11 +108,20 @@ static const response* recipient(str* r)
     return &resp_manyrcpt;
   return 0;
   (void)r;
+  (void)params;
 }
 
 static const response* start(int fd)
 {
   unsigned long maxhops;
+  minenv("maxmsgs", "MAXMSGS");
+  if (msg_count >= session_getnum("maxmsgs", ~0UL))
+    return &resp_manymsgs;
+  if (session_getenv("MAXRCPTS_REJECT")){
+    unsigned long maxrcpts = minenv("maxrcpts", "MAXRCPTS");
+    if (maxrcpts > 0 && rcpt_count > maxrcpts)
+      return &resp_manyrcpt;
+  }
   minenv("maxdatabytes", "DATABYTES");
   if ((maxhops = session_getenvu("MAXHOPS")) == 0)
     maxhops = 100;
@@ -126,12 +182,26 @@ static const response* block(const char* bytes, unsigned long len)
   return 0;
 }
 
+static const response* end(int fd)
+{
+  if (session_getenv("MAXRCPTS_REJECT")){
+    unsigned long maxrcpts = minenv("maxrcpts", "MAXRCPTS");
+    if (maxrcpts > 0 && rcpt_count > maxrcpts)
+      return &resp_manyrcpt;
+  }
+  ++msg_count;
+  return 0;
+  (void)fd;
+}
+
 struct plugin plugin = {
   .version = PLUGIN_VERSION,
   .init = init,
+  .helo = helo,
   .reset = reset,
   .sender = sender,
   .recipient = recipient,
   .data_start = start,
   .data_block = block,
+  .message_end = end,
 };
