@@ -626,109 +626,109 @@ END_OF_TEST_RESULTS
 
 ##### Test tests/plugin-rbl #####
 
-runtest() {
-local ip="$1"
-local queuedir="$2"
-
-export RBL_BLACKLISTS=sbl-xbl.spamhaus.org
-export RBL_DEBUG=1
-export TCPREMOTEIP=$ip
-
-setup_queuedir
-if $queuedir
-then
-    export RBL_QUEUEDIR=$QUEUEDIR
-fi
-
-smtpfront echo rbl accept <<EOF
-HELO me
-MAIL FROM:<somewhere>
-RCPT TO:<elsewhere>
-DATA
-Subject: test
-.
-EOF
-
-dump_queuedir
-
-cleanup_queuedir
-
-unset RBL_BLACKLISTS RBL_DEBUG RBL_QUEUEDIR TCPLOCALIP QUEUEDIR
-rm -rf $tmp/queuedir $tmp/queuedir
-}
-vecho "Running test tests/plugin-rbl '127.0.0.2' 'false'"
-run_compare_test tests/plugin-rbl '127.0.0.2' 'false' <<END_OF_TEST_RESULTS
-mailfront[#]: rbl: sbl-xbl.spamhaus.org:
-mailfront[#]: http://www.spamhaus.org/sbl/query/SBL233
-mailfront[#]: http://www.spamhaus.org/query/bl?ip=127.0.0.2
-250 local.host^M
-mailfront[#]: MAIL FROM:<somewhere>
-mailfront[#]: 451 Blocked: http://www.spamhaus.org/sbl/query/SBL233
-451 Blocked: http://www.spamhaus.org/sbl/query/SBL233^M
-mailfront[#]: RCPT TO:<elsewhere>
-mailfront[#]: 503 5.5.1 You must send MAIL FROM: first
-503 5.5.1 You must send MAIL FROM: first^M
-mailfront[#]: 503 5.5.1 You must send MAIL FROM: first
-503 5.5.1 You must send MAIL FROM: first^M
-mailfront[#]: Subject: test
-mailfront[#]: 500 5.5.1 Not implemented.
-500 5.5.1 Not implemented.^M
-mailfront[#]: . 
-mailfront[#]: 500 5.5.1 Not implemented.
-500 5.5.1 Not implemented.^M
-mailfront[#]: bytes in: 71 bytes out: 243
-queuedir tmp: 0 new: 0
-END_OF_TEST_RESULTS
-
-vecho "Running test tests/plugin-rbl '127.0.0.2' 'true'"
-run_compare_test tests/plugin-rbl '127.0.0.2' 'true' <<END_OF_TEST_RESULTS
-mailfront[#]: rbl: sbl-xbl.spamhaus.org:
-mailfront[#]: http://www.spamhaus.org/sbl/query/SBL233
-mailfront[#]: http://www.spamhaus.org/query/bl?ip=127.0.0.2
-250 local.host^M
-mailfront[#]: MAIL FROM:<somewhere>
-250 Sender='somewhere'.^M
-mailfront[#]: RCPT TO:<elsewhere>
-250 Recipient='elsewhere'.^M
-354 End your message with a period on a line by itself.^M
-mailfront[#]: Subject: test
-mailfront[#]: 451 Blocked: http://www.spamhaus.org/sbl/query/SBL233
-451 Blocked: http://www.spamhaus.org/sbl/query/SBL233^M
-mailfront[#]: bytes in: 71 bytes out: 213
-queuedir tmp: 0 new: 1
-===== queued file =====
-somewhere^@elsewhere^@^@Subject: test
-=====
-END_OF_TEST_RESULTS
-
-vecho "Running test tests/plugin-rbl '127.0.0.99' 'false'"
-run_compare_test tests/plugin-rbl '127.0.0.99' 'false' <<END_OF_TEST_RESULTS
-250 local.host^M
-mailfront[#]: MAIL FROM:<somewhere>
-250 Sender='somewhere'.^M
-mailfront[#]: RCPT TO:<elsewhere>
-250 Recipient='elsewhere'.^M
-354 End your message with a period on a line by itself.^M
-mailfront[#]: Subject: test
-250 Received 14 bytes.^M
-mailfront[#]: bytes in: 71 bytes out: 182
-queuedir tmp: 0 new: 0
-END_OF_TEST_RESULTS
-
-vecho "Running test tests/plugin-rbl '127.0.0.99' 'true'"
-run_compare_test tests/plugin-rbl '127.0.0.99' 'true' <<END_OF_TEST_RESULTS
-250 local.host^M
-mailfront[#]: MAIL FROM:<somewhere>
-250 Sender='somewhere'.^M
-mailfront[#]: RCPT TO:<elsewhere>
-250 Recipient='elsewhere'.^M
-354 End your message with a period on a line by itself.^M
-mailfront[#]: Subject: test
-250 Received 14 bytes.^M
-mailfront[#]: bytes in: 71 bytes out: 182
-queuedir tmp: 0 new: 0
-END_OF_TEST_RESULTS
-
+#runtest() {
+#local ip="$1"
+#local queuedir="$2"
+#
+#export RBL_BLACKLISTS=sbl-xbl.spamhaus.org
+#export RBL_DEBUG=1
+#export TCPREMOTEIP=$ip
+#
+#setup_queuedir
+#if $queuedir
+#then
+#    export RBL_QUEUEDIR=$QUEUEDIR
+#fi
+#
+#smtpfront echo rbl accept <<EOF
+#HELO me
+#MAIL FROM:<somewhere>
+#RCPT TO:<elsewhere>
+#DATA
+#Subject: test
+#.
+#EOF
+#
+#dump_queuedir
+#
+#cleanup_queuedir
+#
+#unset RBL_BLACKLISTS RBL_DEBUG RBL_QUEUEDIR TCPLOCALIP QUEUEDIR
+#rm -rf $tmp/queuedir $tmp/queuedir
+#}
+#vecho "Running test tests/plugin-rbl '127.0.0.2' 'false'"
+#run_compare_test tests/plugin-rbl '127.0.0.2' 'false' <<END_OF_TEST_RESULTS
+#mailfront[#]: rbl: sbl-xbl.spamhaus.org:
+#mailfront[#]: http://www.spamhaus.org/sbl/query/SBL233
+#mailfront[#]: http://www.spamhaus.org/query/bl?ip=127.0.0.2
+#250 local.host^M
+#mailfront[#]: MAIL FROM:<somewhere>
+#mailfront[#]: 451 Blocked: http://www.spamhaus.org/sbl/query/SBL233
+#451 Blocked: http://www.spamhaus.org/sbl/query/SBL233^M
+#mailfront[#]: RCPT TO:<elsewhere>
+#mailfront[#]: 503 5.5.1 You must send MAIL FROM: first
+#503 5.5.1 You must send MAIL FROM: first^M
+#mailfront[#]: 503 5.5.1 You must send MAIL FROM: first
+#503 5.5.1 You must send MAIL FROM: first^M
+#mailfront[#]: Subject: test
+#mailfront[#]: 500 5.5.1 Not implemented.
+#500 5.5.1 Not implemented.^M
+#mailfront[#]: . 
+#mailfront[#]: 500 5.5.1 Not implemented.
+#500 5.5.1 Not implemented.^M
+#mailfront[#]: bytes in: 71 bytes out: 243
+#queuedir tmp: 0 new: 0
+#END_OF_TEST_RESULTS
+#
+#vecho "Running test tests/plugin-rbl '127.0.0.2' 'true'"
+#run_compare_test tests/plugin-rbl '127.0.0.2' 'true' <<END_OF_TEST_RESULTS
+#mailfront[#]: rbl: sbl-xbl.spamhaus.org:
+#mailfront[#]: http://www.spamhaus.org/sbl/query/SBL233
+#mailfront[#]: http://www.spamhaus.org/query/bl?ip=127.0.0.2
+#250 local.host^M
+#mailfront[#]: MAIL FROM:<somewhere>
+#250 Sender='somewhere'.^M
+#mailfront[#]: RCPT TO:<elsewhere>
+#250 Recipient='elsewhere'.^M
+#354 End your message with a period on a line by itself.^M
+#mailfront[#]: Subject: test
+#mailfront[#]: 451 Blocked: http://www.spamhaus.org/sbl/query/SBL233
+#451 Blocked: http://www.spamhaus.org/sbl/query/SBL233^M
+#mailfront[#]: bytes in: 71 bytes out: 213
+#queuedir tmp: 0 new: 1
+#===== queued file =====
+#somewhere^@elsewhere^@^@Subject: test
+#=====
+#END_OF_TEST_RESULTS
+#
+#vecho "Running test tests/plugin-rbl '127.0.0.99' 'false'"
+#run_compare_test tests/plugin-rbl '127.0.0.99' 'false' <<END_OF_TEST_RESULTS
+#250 local.host^M
+#mailfront[#]: MAIL FROM:<somewhere>
+#250 Sender='somewhere'.^M
+#mailfront[#]: RCPT TO:<elsewhere>
+#250 Recipient='elsewhere'.^M
+#354 End your message with a period on a line by itself.^M
+#mailfront[#]: Subject: test
+#250 Received 14 bytes.^M
+#mailfront[#]: bytes in: 71 bytes out: 182
+#queuedir tmp: 0 new: 0
+#END_OF_TEST_RESULTS
+#
+#vecho "Running test tests/plugin-rbl '127.0.0.99' 'true'"
+#run_compare_test tests/plugin-rbl '127.0.0.99' 'true' <<END_OF_TEST_RESULTS
+#250 local.host^M
+#mailfront[#]: MAIL FROM:<somewhere>
+#250 Sender='somewhere'.^M
+#mailfront[#]: RCPT TO:<elsewhere>
+#250 Recipient='elsewhere'.^M
+#354 End your message with a period on a line by itself.^M
+#mailfront[#]: Subject: test
+#250 Received 14 bytes.^M
+#mailfront[#]: bytes in: 71 bytes out: 182
+#queuedir tmp: 0 new: 0
+#END_OF_TEST_RESULTS
+#
 
 ##### Test tests/rules-empty #####
 
